==> bob.db.msu_mfsd_mod-2.2.2-py_0.tar.bz2: link.py <==
DATA = {
  "Examples": [], 
  "dist": "bob.db.msu_mfsd_mod-2.2.2-py_0", 
  "python-scripts": [], 
  "site-packages": [
    "bob.db.msu_mfsd_mod-2.2.2-py3.6.egg-info/PKG-INFO", 
    "bob.db.msu_mfsd_mod-2.2.2-py3.6.egg-info/SOURCES.txt", 
    "bob.db.msu_mfsd_mod-2.2.2-py3.6.egg-info/dependency_links.txt", 
    "bob.db.msu_mfsd_mod-2.2.2-py3.6.egg-info/entry_points.txt", 
    "bob.db.msu_mfsd_mod-2.2.2-py3.6.egg-info/not-zip-safe", 
    "bob.db.msu_mfsd_mod-2.2.2-py3.6.egg-info/requires.txt", 
    "bob.db.msu_mfsd_mod-2.2.2-py3.6.egg-info/top_level.txt", 
    "bob/db/msu_mfsd_mod/__init__.py", 
    "bob/db/msu_mfsd_mod/create.py", 
    "bob/db/msu_mfsd_mod/db.sql3", 
    "bob/db/msu_mfsd_mod/driver.py", 
    "bob/db/msu_mfsd_mod/folds/clients_fold1.txt", 
    "bob/db/msu_mfsd_mod/folds/clients_fold2.txt", 
    "bob/db/msu_mfsd_mod/folds/clients_fold3.txt", 
    "bob/db/msu_mfsd_mod/folds/clients_fold4.txt", 
    "bob/db/msu_mfsd_mod/folds/clients_fold5.txt", 
    "bob/db/msu_mfsd_mod/folds/msu_mfsd_mod_attackvids.txt", 
    "bob/db/msu_mfsd_mod/folds/msu_mfsd_mod_realvids.txt", 
    "bob/db/msu_mfsd_mod/folds/test_clients.txt", 
    "bob/db/msu_mfsd_mod/folds/test_sub_list.txt", 
    "bob/db/msu_mfsd_mod/folds/train_clients_1.txt", 
    "bob/db/msu_mfsd_mod/folds/train_clients_2.txt", 
    "bob/db/msu_mfsd_mod/folds/train_clients_3.txt", 
    "bob/db/msu_mfsd_mod/folds/train_clients_4.txt", 
    "bob/db/msu_mfsd_mod/folds/train_clients_5.txt", 
    "bob/db/msu_mfsd_mod/folds/train_sub_list.txt", 
    "bob/db/msu_mfsd_mod/models.py", 
    "bob/db/msu_mfsd_mod/query.py", 
    "bob/db/msu_mfsd_mod/rotated_videos/rotated_videos.txt", 
    "bob/db/msu_mfsd_mod/test.py", 
    "bob/db/msu_mfsd_mod/test_images/real/real_client005_android_SD_scene01.mp4", 
    "bob/db/msu_mfsd_mod/test_images/real/real_client022_android_SD_scene01.mp4", 
    "bob/db/msu_mfsd_mod/test_images/real_client005_android_SD_scene01_frame0_correct.hdf5", 
    "bob/db/msu_mfsd_mod/test_images/real_client022_android_SD_scene01_frame0_correct.hdf5", 
    "bob/db/msu_mfsd_mod/testme.py", 
    "bob/db/msu_mfsd_mod/verificationprotocol.py"
  ]
}
## END DATA

"""
This is code that is added to noarch Python packages. See
conda_build/noarch_python.py.

"""
import os
from os.path import dirname, exists, isdir, join, normpath
import sys
import shutil


# Silence pyflakes. This variable is added when link.py is written by
# conda_build.noarch_python.
if False:
    DATA = None

THIS_DIR = dirname(__file__)
PREFIX = normpath(sys.prefix)
if sys.platform == 'win32':
    BIN_DIR = join(PREFIX, 'Scripts')
    SITE_PACKAGES = 'Lib/site-packages'
else:
    BIN_DIR = join(PREFIX, 'bin')
    SITE_PACKAGES = 'lib/python%s/site-packages' % sys.version[:3]

# the list of these files is going to be store in info/_files
FILES = []


def _link(src, dst):
    try:
        os.link(src, dst)
        # on Windows os.link raises AttributeError
    except (OSError, AttributeError):
        shutil.copy2(src, dst)


def _unlink(path):
    try:
        os.unlink(path)
    except OSError:
        pass


def pyc_f(f, version_info=sys.version_info):
    if version_info[0] == 2:
        return f + 'c'
    dn, fn = f.rsplit('/', 1)
    return '%s/__pycache__/%s.cpython-%d%d.pyc' % (
              dn, fn[:-3], version_info[0], version_info[1])


def link_files(src_root, dst_root, files):
    for f in files:
        src = join(THIS_DIR, src_root, f)
        dst = join(PREFIX, dst_root, f)
        dst_dir = dirname(dst)
        if not isdir(dst_dir):
            os.makedirs(dst_dir)
        if exists(dst):
            _unlink(dst)
        _link(src, dst)
        f = '%s/%s' % (dst_root, f)
        FILES.append(f)
        if f.endswith('.py'):
            FILES.append(pyc_f(f))


def create_script(fn):
    src = join(THIS_DIR, 'python-scripts', fn)
    dst = join(BIN_DIR, fn)
    if sys.platform == 'win32':
        shutil.copy2(src, dst + '-script.py')
        FILES.append('Scripts/%s-script.py' % fn)
        shutil.copy2(join(THIS_DIR,
                          'cli-%d.exe' % (8 * tuple.__itemsize__)),
                     dst + '.exe')
        FILES.append('Scripts/%s.exe' % fn)
    else:
        with open(src) as fi:
            data = fi.read()
        with open(dst, 'w') as fo:
            fo.write('#!%s\n' % normpath(sys.executable))
            fo.write(data)
        os.chmod(dst, 0o775)
        FILES.append('bin/%s' % fn)


def create_scripts(files):
    if not files:
        return
    if not isdir(BIN_DIR):
        os.mkdir(BIN_DIR)
    for fn in files:
        create_script(fn)


def main():
    create_scripts(DATA['python-scripts'])
    link_files('site-packages', SITE_PACKAGES, DATA['site-packages'])
    link_files('Examples', 'Examples', DATA['Examples'])

    with open(join(PREFIX, 'conda-meta',
                   '%s.files' % DATA['dist']), 'w') as fo:
        for f in FILES:
            fo.write('%s\n' % f)


if __name__ == '__main__':
    main()

==> bob.db.msu_mfsd_mod-2.2.3-py_0.tar.bz2: link.py <==
DATA = {
  "Examples": [], 
  "dist": "bob.db.msu_mfsd_mod-2.2.3-py_0", 
  "python-scripts": [], 
  "site-packages": [
    "bob/db/msu_mfsd_mod/folds/clients_fold5.txt", 
    "bob/db/msu_mfsd_mod/__init__.py", 
    "bob/db/msu_mfsd_mod/test_images/real_client005_android_SD_scene01_frame0_correct.hdf5", 
    "bob/db/msu_mfsd_mod/create.py", 
    "bob/db/msu_mfsd_mod/folds/clients_fold2.txt", 
    "bob.db.msu_mfsd_mod-2.2.3-py3.6.egg-info/entry_points.txt", 
    "bob/db/msu_mfsd_mod/driver.py", 
    "bob/db/msu_mfsd_mod/query.py", 
    "bob/db/msu_mfsd_mod/rotated_videos/rotated_videos.txt", 
    "bob/db/msu_mfsd_mod/folds/train_clients_3.txt", 
    "bob/db/msu_mfsd_mod/folds/test_sub_list.txt", 
    "bob/db/msu_mfsd_mod/test_images/real/real_client022_android_SD_scene01.mp4", 
    "bob/db/msu_mfsd_mod/folds/train_clients_4.txt", 
    "bob/db/msu_mfsd_mod/folds/msu_mfsd_mod_realvids.txt", 
    "bob.db.msu_mfsd_mod-2.2.3-py3.6.egg-info/top_level.txt", 
    "bob/db/msu_mfsd_mod/folds/train_clients_1.txt", 
    "bob/db/msu_mfsd_mod/folds/test_clients.txt", 
    "bob/db/msu_mfsd_mod/verificationprotocol.py", 
    "bob.db.msu_mfsd_mod-2.2.3-py3.6.egg-info/PKG-INFO", 
    "bob/db/msu_mfsd_mod/folds/train_clients_5.txt", 
    "bob/db/msu_mfsd_mod/folds/clients_fold3.txt", 
    "bob/db/msu_mfsd_mod/models.py", 
    "bob/db/msu_mfsd_mod/db.sql3", 
    "bob/db/msu_mfsd_mod/test_images/real_client022_android_SD_scene01_frame0_correct.hdf5", 
    "bob/db/msu_mfsd_mod/folds/clients_fold1.txt", 
    "bob.db.msu_mfsd_mod-2.2.3-py3.6.egg-info/dependency_links.txt", 
    "bob/db/msu_mfsd_mod/testme.py", 
    "bob/db/msu_mfsd_mod/test_images/real/real_client005_android_SD_scene01.mp4", 
    "bob/db/msu_mfsd_mod/folds/train_clients_2.txt", 
    "bob/db/msu_mfsd_mod/folds/clients_fold4.txt", 
    "bob.db.msu_mfsd_mod-2.2.3-py3.6.egg-info/SOURCES.txt", 
    "bob/db/msu_mfsd_mod/test.py", 
    "bob/db/msu_mfsd_mod/folds/train_sub_list.txt", 
    "bob/db/msu_mfsd_mod/folds/msu_mfsd_mod_attackvids.txt", 
    "bob.db.msu_mfsd_mod-2.2.3-py3.6.egg-info/not-zip-safe", 
    "bob.db.msu_mfsd_mod-2.2.3-py3.6.egg-info/requires.txt"
  ]
}
## END DATA

"""
This is code that is added to noarch Python packages. See
conda_build/noarch_python.py.

"""
import os
from os.path import dirname, exists, isdir, join, normpath
import re
import sys
import shutil


# Silence pyflakes. This variable is added when link.py is written by
# conda_build.noarch_python.
if False:
    DATA = None

THIS_DIR = dirname(__file__)
PREFIX = normpath(sys.prefix)
if sys.platform == 'win32':
    BIN_DIR = join(PREFIX, 'Scripts')
    SITE_PACKAGES = 'Lib/site-packages'
else:
    BIN_DIR = join(PREFIX, 'bin')
    SITE_PACKAGES = 'lib/python%s/site-packages' % sys.version[:3]

# the list of these files is going to be store in info/_files
FILES = []

# three capture groups: whole_shebang, executable, options
SHEBANG_REGEX = (br'^(#!'  # pretty much the whole match string
                 br'(?:[ ]*)'  # allow spaces between #! and beginning of the executable path
                 br'(/(?:\\ |[^ \n\r\t])*)'  # the executable is the next text block without an escaped space or non-space whitespace character  # NOQA
                 br'(.*)'  # the rest of the line can contain option flags
                 br')$')  # end whole_shebang group


def _link(src, dst):
    try:
        os.link(src, dst)
        # on Windows os.link raises AttributeError
    except (OSError, AttributeError):
        shutil.copy2(src, dst)


def _unlink(path):
    try:
        os.unlink(path)
    except OSError:
        pass


def pyc_f(f, version_info=sys.version_info):
    if version_info[0] == 2:
        return f + 'c'
    dn, fn = f.rsplit('/', 1)
    return '%s/__pycache__/%s.cpython-%d%d.pyc' % (
              dn, fn[:-3], version_info[0], version_info[1])


def link_files(src_root, dst_root, files):
    for f in files:
        src = join(THIS_DIR, src_root, f)
        dst = join(PREFIX, dst_root, f)
        dst_dir = dirname(dst)
        if not isdir(dst_dir):
            os.makedirs(dst_dir)
        if exists(dst):
            _unlink(dst)
        _link(src, dst)
        f = '%s/%s' % (dst_root, f)
        FILES.append(f)
        if f.endswith('.py'):
            FILES.append(pyc_f(f))


# yanked from conda
def replace_long_shebang(data):
    # this function only changes a shebang line if it exists and is greater than 127 characters
    if hasattr(data, 'encode'):
        data = data.encode()
    shebang_match = re.match(SHEBANG_REGEX, data, re.MULTILINE)
    if shebang_match:
        whole_shebang, executable, options = shebang_match.groups()
        if len(whole_shebang) > 127:
            executable_name = executable.decode('utf-8').split('/')[-1]
            new_shebang = '#!/usr/bin/env %s%s' % (executable_name, options.decode('utf-8'))
            data = data.replace(whole_shebang, new_shebang.encode('utf-8'))
    if hasattr(data, 'decode'):
        data = data.decode()
    return data


def create_script(fn):
    src = join(THIS_DIR, 'python-scripts', fn)
    dst = join(BIN_DIR, fn)
    if sys.platform == 'win32':
        shutil.copy2(src, dst + '-script.py')
        FILES.append('Scripts/%s-script.py' % fn)
        shutil.copy2(join(THIS_DIR,
                          'cli-%d.exe' % (8 * tuple.__itemsize__)),
                     dst + '.exe')
        FILES.append('Scripts/%s.exe' % fn)
    else:
        with open(src) as fi:
            data = fi.read()
        with open(dst, 'w') as fo:
            shebang = replace_long_shebang('#!%s\n' % normpath(sys.executable))
            fo.write(shebang)
            fo.write(data)
        os.chmod(dst, 0o775)
        FILES.append('bin/%s' % fn)


def create_scripts(files):
    if not files:
        return
    if not isdir(BIN_DIR):
        os.mkdir(BIN_DIR)
    for fn in files:
        create_script(fn)


def main():
    create_scripts(DATA['python-scripts'])
    link_files('site-packages', SITE_PACKAGES, DATA['site-packages'])
    link_files('Examples', 'Examples', DATA['Examples'])

    with open(join(PREFIX, 'conda-meta',
                   '%s.files' % DATA['dist']), 'w') as fo:
        for f in FILES:
            fo.write('%s\n' % f)


if __name__ == '__main__':
    main()
